************************
SyMuRBench Documentation
************************

Welcome to the documentation for **SyMuRBench**, a benchmarking framework for symbolic music understanding and retrieval tasks. This guide will help you get started quickly and make full use of the library.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   installation

.. toctree::
   :maxdepth: 2
   :caption: Usage Examples

   examples/run_with_precomputed_feats
   examples/run_and_cache_features
   examples/run_from_config
   examples/run_from_yaml
   examples/save_results

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
